@@ -1,11 +1,13 @@
-from .dummy_job import dummy_job
+from ..tasks.evaluator_task import evaluator_task
 from .extract_summary_job import extract_summary_job
+from .keywords_enrichment_job import keywords_enrichment_job
 from .target_industries_job import target_industries_job
 from .target_industries_mentions_job import target_industries_mentions_job
 
 __all__ = [
-    "dummy_job",
     "target_industries_job",
     "target_industries_mentions_job",
     "extract_summary_job",
+    "keywords_enrichment_job",
+    "evaluator_task",
 ]
