@@ -3,6 +3,7 @@ from typing import Any, List
 from .csv_loader import CSVLoader
 from .json_loader import JSONLoader
 from .loader import IDENTIFIER, Loader
+from .numpy_loader import NumpyLoader
 from .text_loader import TextLoader
 from .xlsx_loader import XLSXLoader
 
@@ -26,6 +27,8 @@ class FileLoader(Loader):
             self.data = TextLoader(self.filepath).load()
         elif self.filepath.endswith(".xlsx"):
             self.data = XLSXLoader(self.filepath).load()
+        elif self.filepath.endswith(".npy"):
+            self.data = NumpyLoader(self.filepath).load()
         else:
             raise ValueError(
                 "Filepath permitted extension can only be '.csv', '.txt', "
