@@ -14,11 +14,13 @@ class JSONLoader(Loader):
     def __init__(
         self, filepath: str, data: Optional[Union[List[Any], Dict[Any, Any]]] = None
     ):
-        self.filepath = filepath
+        self.filepath = path.join(PROJECT_DIR, filepath)
         self.data: Union[List[Any], Dict[Any, Any]] = data or []
 
-    def load(self):
-        with open(path.join(PROJECT_DIR, self.filepath), encoding="utf-8") as f:
+    def load(self, new_filepath: str = "") -> Any:
+        if new_filepath:
+            self.filepath = new_filepath
+        with open(self.filepath, encoding="utf-8") as f:
             self.data = json.load(f)
         return self.data
 
