@@ -50,3 +50,15 @@ def test_file_loader():
     with pytest.raises(ValueError):
         loader = FileLoader(filepath="loaders/tests/a.yml")
         loader.load()
+
+    loader = FileLoader(filepath="loaders/tests/dummy_json.json")
+    assert len(loader.load()) == 2
+
+    loader = FileLoader(filepath="loaders/tests/test.npy")
+    assert len(loader.load()) == 4
+
+    loader = FileLoader(filepath="loaders/tests/a.xlsx")
+    assert len(loader.load()) == 4
+
+    loader = FileLoader(filepath="loaders/tests/a.txt")
+    assert len(loader.load()) == 14
