@@ -1,3 +1,5 @@
+from typing import Any, Dict
+
 import json
 import os
 
@@ -24,6 +26,8 @@ def test_json_loader():
 
     loader = JSONLoader(filepath="loaders/tests/dummy_json.json")
     loader.load()
+    data: Dict[Any, Any] = dict(loader.data)
+    assert data.get("a") == 1
 
     with pytest.raises(json.decoder.JSONDecodeError):
         loader = JSONLoader(filepath="loaders/tests/dummy_json_broken.json")
