@@ -3,5 +3,5 @@ from apadata.loaders.numpy_loader import NumpyLoader
 
 def test_numpy_loader():
     """Test NumpyLoader"""
-    data = NumpyLoader(filepath="text_processors/tests/evaluators/test.npy").load()
+    data = NumpyLoader(filepath="loaders/tests/test.npy").load()
     assert len(data) == 4
