@@ -10,7 +10,7 @@ from .loader import IDENTIFIER, Loader
 
 
 class XLSXLoader(Loader):
-    """CSV data loader"""
+    """XLSX data loader"""
 
     def __init__(self, filepath: str, delimiter: str = ","):
         self.filepath = filepath
