@@ -9,7 +9,7 @@ class Domain(models.Model):
 
     domain = models.CharField(max_length=255, primary_key=True)
     target_industries = models.ManyToManyField(
-        "Industry", related_name="domains", through="DomainTargetIndustries"
+        "ExternalIndustry", related_name="domains", through="DomainTargetIndustries"
     )
 
     @staticmethod
