@@ -1,7 +1,7 @@
 from django.db import models
 
 from apadata.models.domain import Domain
-from apadata.models.industry import Industry
+from apadata.models.externalindustry import ExternalIndustry
 
 
 class DomainTargetIndustries(models.Model):
@@ -12,7 +12,7 @@ class DomainTargetIndustries(models.Model):
         on_delete=models.CASCADE,
     )
     target_industries = models.ForeignKey(
-        Industry,
+        ExternalIndustry,
         on_delete=models.CASCADE,
     )
     created_at = models.DateField(auto_now_add=True)
