@@ -21,7 +21,7 @@ class SpellingEvaluatorModule(PipelineModule[Input, Output]):
     def run(self, context: PipelineContext) -> Output:
         keyword = context.search_field("keyword")
         language = context.search_field("language")
-        evaluator = SpellingEvaluator()
-        score = evaluator.evaluate(keyword, language=language)
+        evaluator = SpellingEvaluator(language=language)
+        score = evaluator.evaluate(keyword)
         context.add("spelling_score", score)
         return dict(context.payload)
