@@ -3,6 +3,7 @@ from typing import Any, Dict
 from apadata.pipelines.pipeline_context import PipelineContext
 from apadata.pipelines.pipeline_module import PipelineModule
 from apadata.text_processors.evaluators.synonymy_evaluator import SynonymyEvaluator
+from apadata.text_processors.text_similarity import load_industry_names_embs
 
 Input = Dict[str, Any]
 Output = Dict[str, Any]
@@ -20,7 +21,7 @@ class SynonymyEvaluatorModule(PipelineModule[Input, Output]):
 
     def run(self, context: PipelineContext) -> Output:
         keyword = context.search_field("keyword")
-        evaluator = SynonymyEvaluator()
+        evaluator = SynonymyEvaluator(industry_name_embs=load_industry_names_embs())
         score = evaluator.evaluate(keyword)
         context.add("synonymy_score", score)
         return dict(context.payload)
