@@ -16,13 +16,7 @@ class LangDetectTextProcessorModule(PipelineModule[Input, Output]):
 
     def run(self, context: PipelineContext) -> Output:
         payload: Union[str, Dict[str, Any]] = context.payload
-        if isinstance(payload, dict):
-            text = payload["text"]
-        elif isinstance(payload, str):
-            text = payload
-        else:
-            raise ValueError("Payload should have been a dictionary")
-
+        text = super().get_text_from_payload(payload)
         language_detector = LangDetectTextProcessor(text=text)
         detected_lang = language_detector.detect()
         context.add("language", detected_lang)
