@@ -26,7 +26,9 @@ class TargetIndustriesMentionsModule(PipelineModule[Input, Output]):
             [url.replace("-", " ") for url in urls]
         )
 
-        target_industries_mentions_extractor = TargetIndustriesExtractor()
+        target_industries_mentions_extractor = TargetIndustriesExtractor(
+            text=web_content_with_urls
+        )
         target_industries = (
             target_industries_mentions_extractor.extract_target_industries_mentions(
                 web_content=web_content_with_urls, language=language
