@@ -5,7 +5,10 @@ from apadata.pipelines.pipeline_context import PipelineContext
 
 
 def test_language_frequency_evaluator_module():
-    payload = {"keyword": "Consulting", "language": "en"}
+    payload = {
+        "keyword": "Consulting",
+        "language": "en",
+    }
     context = PipelineContext(payload=payload)
     module = LanguageFrequencyEvaluatorModule()
     module.run(context)
