@@ -11,7 +11,9 @@ def test_low_quality_keywords_evaluator_module():
     module.run(context)
     assert context.search_field("low_quality_keywords_score") == 1.0
 
-    payload = {"keyword": "Consulting United States of America and with stupid idiot"}
+    payload = {
+        "keyword": "Consulting United States of America and with stupid idiot",
+    }
     context = PipelineContext(payload=payload)
     module = LowQualityKeywordsEvaluatorModule()
     module.run(context)
