@@ -1,3 +1,5 @@
+import pytest
+
 from ...pipelines.pipeline_context import PipelineContext
 from ..spacy_text_processor_module import SpacyTextProcessorModule
 
@@ -14,3 +16,9 @@ def test_spacy_text_processor_module():
     context.add("language", "en")
     spacy_client_module.run(context)
     assert context.get("company_names") == ["Apple"]
+
+    bad_payload = 3.14
+    context = PipelineContext(payload=bad_payload)
+    context.add("language", "en")
+    with pytest.raises(ValueError):
+        spacy_client_module.run(context)
