@@ -1,5 +1,5 @@
-from apadata.modules.chat_gpt_module import ChatGptModule
 from apadata.modules.elasticsearch_client_module import ElasticsearchClientModule
+from apadata.modules.summary_module import SummaryModule
 from apadata.pipelines.pipeline import Pipeline
 from apadata.pipelines.pipeline_context import PipelineContext
 
@@ -35,6 +35,6 @@ class SummariesPipeline(Pipeline):
             context,
             [
                 ElasticsearchClientModule(pre_process=move_payload_to_context),
-                ChatGptModule(),
+                SummaryModule(),
             ],
         )
