@@ -1,6 +1,9 @@
+from typing import Callable
+
 from .highest_score_strategy import HighestScoreStrategy
 from .mean_score_strategy import MeanScoreStrategy
 from .score_strategy import ScoreStrategy, ScoreStrategyEnum
+from .weighted_mean_score_strategy import WeightedMeanScoreStrategy
 
 
 class ScoreStrategyFactory:
@@ -9,8 +12,12 @@ class ScoreStrategyFactory:
     STRATEGIES = {
         ScoreStrategyEnum.MEAN: MeanScoreStrategy,
         ScoreStrategyEnum.HIGHEST: HighestScoreStrategy,
+        ScoreStrategyEnum.WEIGHTED_MEAN: WeightedMeanScoreStrategy,
     }
 
     @staticmethod
     def create(strategy: ScoreStrategyEnum) -> ScoreStrategy:
-        return ScoreStrategyFactory.STRATEGIES[strategy]()
+        strategy_class: Callable[[], ScoreStrategy] = ScoreStrategyFactory.STRATEGIES[
+            strategy
+        ]
+        return strategy_class()
