@@ -1,5 +1,3 @@
-from typing import Any
-
 import abc
 
 
@@ -9,7 +7,7 @@ class Evaluator:
     """
 
     @abc.abstractmethod
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         """
         Parameters
         ----------
