@@ -1,5 +1,3 @@
-from typing import Any
-
 from statistics import mean
 
 from nltk.tokenize import word_tokenize
@@ -14,11 +12,9 @@ class LanguageFrequencyEvaluator(Evaluator):
     def __init__(self, language: str):
         self.language = language
 
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         keyword_tokens = word_tokenize(keyword)
         freqs = [
             float(word_frequency(token, self.language)) for token in keyword_tokens
         ]
-        # fixme this is a bit costly in time
-        average_freq = mean(freqs)
-        return average_freq
+        return mean(freqs)
