@@ -1,5 +1,3 @@
-from typing import Any
-
 from apadata.text_processors.evaluators.evaluator import Evaluator
 
 
@@ -10,7 +8,7 @@ class LengthEvaluator(Evaluator):
         self.min_length = min_length
         self.max_length = max_length
 
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         if self.min_length <= len(keyword) <= self.max_length:
             return 1.0
         return 0.0
