@@ -1,5 +1,3 @@
-from typing import Any
-
 import collections
 
 import geostring as geo
@@ -10,7 +8,7 @@ from apadata.text_processors.evaluators.evaluator import Evaluator
 class LocationEvaluator(Evaluator):
     """Evaluates a keyword based on whether it mentions a location or not"""
 
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         words = keyword.split()
         for word in words:
             result = geo.resolve(word)
