@@ -1,5 +1,5 @@
 # pylint: disable-all
-from typing import Any
+from typing import Optional
 
 from spellchecker import SpellChecker
 
@@ -8,14 +8,16 @@ from apadata.text_processors.evaluators.evaluator import Evaluator
 
 
 class SpellingEvaluator(Evaluator):
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
-        language = kwargs["language"]
-        if not language:
-            language = LangDetectTextProcessor(keyword).detect()
-        if not language:
+    def __init__(self, language: Optional[str] = None):
+        self.language = language
+
+    def evaluate(self, keyword: str) -> float:
+        if not self.language:
+            self.language = str(LangDetectTextProcessor(keyword).detect())
+        if not self.language:
             return 1.0
         try:
-            spell_checker = SpellChecker(language=language)
+            spell_checker = SpellChecker(language=self.language)
         except ValueError:
             return 1.0
         if spell_checker.correction(keyword) != keyword:
