@@ -1,4 +1,4 @@
-from typing import Any, List
+from typing import List
 
 from itertools import permutations
 
@@ -19,7 +19,7 @@ class WikipediaEvaluator(Evaluator):
         self.search_all_queries_permutations = search_all_queries_permutations
         self.suggestion = suggestion
 
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         keyword_tokens = word_tokenize(keyword)
 
         keyword_permutations = (
