@@ -18,6 +18,9 @@ class LangDetectTextProcessor(TextProcessor):
     This class will detect the language
     """
 
+    def process(self) -> Optional[str]:
+        return self.detect()
+
     def detect(self) -> Optional[str]:
         if not self.text:
             raise ValueError("Text cannot be empty string or None")
