@@ -18,3 +18,7 @@ def test_elasticsearch_evaluator():
 
     keyword = "Nothing"
     assert evaluator.evaluate(keyword) == 0.0
+
+    evaluator = ElasticsearchEvaluator()
+    keyword = "Text"
+    assert evaluator.evaluate(keyword) == 0.0
