@@ -1,10 +1,8 @@
-from typing import Any
-
 from apadata.text_processors.evaluators.evaluator import Evaluator
 
 
 class MockLengthEvaluator(Evaluator):
-    def evaluate(self, keyword: str, **kwargs: Any) -> float:
+    def evaluate(self, keyword: str) -> float:
         if len(keyword) < 4 or len(keyword) > 60:
             return 0.0
         return 1.0
