@@ -2,10 +2,13 @@ from apadata.text_processors.evaluators.spelling_evaluator import SpellingEvalua
 
 
 def test_spelling_evaluator():
-    evaluator = SpellingEvaluator()
+    language = "en"
+    evaluator = SpellingEvaluator(language=language)
     keyword = "Consulting"
-    language = "en"
-    assert evaluator.evaluate(keyword, language=language) == 1.0
+    assert evaluator.evaluate(keyword) == 1.0
     keyword = "Consutlining"
-    language = "en"
-    assert evaluator.evaluate(keyword, language=language) == 0.0
+    assert evaluator.evaluate(keyword) == 0.0
+    evaluator = SpellingEvaluator()
+    assert evaluator.evaluate("Consulting") == 1.0
+    evaluator = SpellingEvaluator()
+    assert evaluator.evaluate("La revedere amici") == 1.0
