@@ -26,6 +26,10 @@ def test_spacy_text_processor_en():
     assert doc.ents[0].text == "Apple"
     assert doc.ents[0].label_ == "ORG"
 
+    doc, document_entities = spacy_processor.process()
+    assert isinstance(doc, spacy.tokens.doc.Doc)
+    assert len(document_entities) == 6
+
 
 def test_spacy_text_processor_de():
     text = "Er arbeitet bei Apple Gmbh"
@@ -47,3 +51,7 @@ def test_spacy_text_processor_de():
 
     assert doc.ents[0].text == "Apple Gmbh"
     assert doc.ents[0].label_ == "ORG"
+
+    doc, document_entities = spacy_processor.process()
+    assert isinstance(doc, spacy.tokens.doc.Doc)
+    assert len(document_entities) == 6
