@@ -4,7 +4,12 @@ from ..text_similarity import TextSimilarity
 def test_text_similarity_system():
     ts_calculator = TextSimilarity()
     sim_level = 0.8363
-    result = round(ts_calculator.text_similarity("consulting",
-                                                 "consultancy"), 4)
+    result = round(ts_calculator.text_similarity("consulting", "consultancy"), 4)
+    assert isinstance(result, float)
+    assert sim_level == result
+
+    ts_calculator = TextSimilarity("consulting", "consultancy")
+    sim_level = 0.8363
+    result = round(ts_calculator.process(), 4)
     assert isinstance(result, float)
     assert sim_level == result
