@@ -1,3 +1,5 @@
+from typing import Any
+
 import abc
 
 
@@ -14,3 +16,7 @@ class TextProcessor(abc.ABC):
 
     def __init__(self, text: str):
         self.text = text
+
+    @abc.abstractmethod
+    def process(self) -> Any:
+        pass
